%% Bredemeier, Juessen, and Winkler (2022)
% Journal of Money, Credit and Banking
% This file creates Tables 2, 3, and A3 of the paper (tables are saved in spreadshets in folder '_Tables')

% install dynare and add its path in line 13

%% housekeeping
clear;
close all;
clc;

%% add dynare path here
addpath('C:/dynare/dynare-4.6.1/matlab')

%% options
indi_time  = [1 4 16];
pause_time = 3;

%% units
ss_gdp   = 21433.226/4;     % billions of dollars (2019 annual divided by 4 to obtain per quarter value)
unit_emp = 0.238 * 150935;  % blue-collar share * thousands of jobs (2019 total average)

% transfer to job years per $100K
ss_gdp   = ss_gdp*10000;  % from 1B-increments to 100K-increments
unit_emp = unit_emp*1000; % from thousands of jobs to jobs

%% loop over calibrations
models = {'baseline','Taylor','adjustment','utilization','wealth','sticky'};
NM = 6;

for mm = 1:6
    model = models{mm};
       
    %% parameters
    
    %baseline parameters:
    delta_g_sensi = -0.3640;  % baseline is -0.3640;
    
    zeta_g_sensi  = -0.0685;  % baseline is -0.0685;
    zeta_g1_sensi =  0.23106;  % baseline is  0.23106;
    zeta_g2_sensi = -0.368279;  % baseline is -0.368279;
    
    kappa          = 1.85;
    kappa_diff     = 1.8;
    kappa_b1_sensi = 1/kappa_diff*kappa;
    kappa_p1_sensi = 1/kappa_diff*kappa;
    kappa_w1_sensi = 1/kappa_diff*kappa;
    kappa_b2_sensi = kappa_diff*kappa;
    kappa_p2_sensi = kappa_diff*kappa;
    kappa_w2_sensi = kappa_diff*kappa;
    
    u_elast_sensi = 3;
    xi_sensi      = 0.0001;
    calvo_sensi   = 2/3;
    
    sigma_mat  = [0 0 0 0 0 0];
    
    % change parameters depending on 'model':
    switch(model)
        case('Taylor')
            delta_g_sensi =  0;         % baseline is -0.3640;
            zeta_g_sensi  = -0.0521;    % baseline is -0.0685;
            zeta_g1_sensi =  0.247445;  % baseline is  0.23106;
            zeta_g2_sensi = -0.35167;   % baseline is -0.368279;
        case('adjustment')
            kappa_b1_sensi = 1.85;
            kappa_p1_sensi = 1.85;
            kappa_w1_sensi = 1.85;
            kappa_b2_sensi = 1.85;
            kappa_p2_sensi = 1.85;
            kappa_w2_sensi = 1.85;
            zeta_g_sensi   = -0.05795;    % baseline is -0.0685;
            zeta_g1_sensi  =  0.2395;   % baseline is  0.23106;
            zeta_g2_sensi  = -0.3554;   % baseline is -0.368279;
        case('utilization')
            u_elast_sensi = 0.001;
            zeta_g_sensi  = -0.04505;    % baseline is -0.0685;
            zeta_g1_sensi =  0.29999;    % baseline is  0.23106;
            zeta_g2_sensi = -0.3901;     % baseline is -0.368279;
        case('wealth')
            xi_sensi      = 1;
            zeta_g_sensi  = -0.06767;
            zeta_g1_sensi =  0.23188;
            zeta_g2_sensi = -0.367265;
        case('sticky')
            calvo_sensi = 0.5;
            zeta_g_sensi  = -0.05475;
            zeta_g1_sensi =  0.24581;
            zeta_g2_sensi = -0.35535;
    end
    
    
    %% ========================================================================
    %% symmetric g and tax shocks
    
    sigma_tax  = [1 1];
    sigma_matG = [1 zeta_g_sensi];
    
    dynare BJW_model_sensi;
    
    %% calculate moments
    [block_g,multi_g]     = calc_moms(n_agg_eps_g,nb_eps_g,np_eps_g,nw_eps_g,n1_eps_g,n2_eps_g,def_eps_g,gdp_bar,indi_time,unit_emp,ss_gdp);
    [block_tau,multi_tau] = calc_moms(n_agg_eps_tau,nb_eps_tau,np_eps_tau,nw_eps_tau,n1_eps_tau,n2_eps_tau,def_eps_tau,gdp_bar,indi_time,unit_emp,ss_gdp);
    multi = [multi_g; multi_tau];
    
    sp_mul = y_eps_g(1)/g_eps_g(1);
    
    %% ========================================================================
    %% Labor tax shock und G1 shock
    
    sigma_tax=[1 0];
    sigma_matG=[1 zeta_g1_sensi];
    
    dynare BJW_model_sensi;
    
    %% calculate moments
    [block_g1,multi_g]     = calc_moms(n_agg_eps_g,nb_eps_g,np_eps_g,nw_eps_g,n1_eps_g,n2_eps_g,def_eps_g,gdp_bar,indi_time,unit_emp,ss_gdp);
    [block_taul,multi_tau] = calc_moms(n_agg_eps_tau,nb_eps_tau,np_eps_tau,nw_eps_tau,n1_eps_tau,n2_eps_tau,def_eps_tau,gdp_bar,indi_time,unit_emp,ss_gdp);
    multi1 = [multi_g; multi_tau];
    
    %% ========================================================================
    %% Capital tax shock and G2 shock
    sigma_tax=[0 1];
    sigma_matG=[1 zeta_g2_sensi];
    
    dynare BJW_model_sensi;
    
    %% calculate moments
    [block_g2,multi_g]     = calc_moms(n_agg_eps_g,nb_eps_g,np_eps_g,nw_eps_g,n1_eps_g,n2_eps_g,def_eps_g,gdp_bar,indi_time,unit_emp,ss_gdp);
    [block_tauk,multi_tau] = calc_moms(n_agg_eps_tau,nb_eps_tau,np_eps_tau,nw_eps_tau,n1_eps_tau,n2_eps_tau,def_eps_tau,gdp_bar,indi_time,unit_emp,ss_gdp);
    multi2 = [multi_g; multi_tau];
    
    %% ========================================================================
    %% collect and save
    
    results = [block_g block_g1 block_g2 block_tau block_taul block_tauk];
    xlswrite('_Tables\TableA3',results,model);
    
    switch model
        case('baseline')
            xlswrite('_Tables\Table2',results);
            xlswrite('_Tables\Table3',[multi(1:3) multi1(1:3) multi2(1:3) multi(4:6) multi1(4:6) multi2(4:6)])
    end
    
end


%% ========================================================================
%% FUNCTIONS
%% ========================================================================

%% calculate %moments for the sensitivity checks

function [block_shock,multi_shock] = calc_moms(n_agg_eps_shock,nb_eps_shock,np_eps_shock,nw_eps_shock,n1_eps_shock,n2_eps_shock,def_eps_shock,gdp_bar,indi_time,unit_emp,ss_gdp)
n_shock_cum   = cumsum(n_agg_eps_shock);
nb_shock_cum  = cumsum(nb_eps_shock);
np_shock_cum  = cumsum(np_eps_shock);
nw_shock_cum  = cumsum(nw_eps_shock);
n1_shock_cum  = cumsum(n1_eps_shock);
n2_shock_cum  = cumsum(n2_eps_shock);
def_shock_cum = cumsum(def_eps_shock)/gdp_bar;

nb_shock_rel = nb_shock_cum./n_shock_cum;
np_shock_rel = np_shock_cum./n_shock_cum;
nw_shock_rel = nw_shock_cum./n_shock_cum;
n1_shock_rel = n1_shock_cum./n_shock_cum;
n2_shock_rel = n2_shock_cum./n_shock_cum;

multi_shock = 1/4*n_shock_cum*unit_emp./(def_shock_cum*ss_gdp);

block_shock   = [ n1_shock_rel(indi_time) np_shock_rel(indi_time) nb_shock_rel(indi_time)];
multi_shock   = multi_shock(indi_time);
end